import bpy # type: ignore
from bpy.types import Header, Menu, Panel, Operator # type: ignore
from . import warnings_rules

bl_info = {
    "name": "Enhanced Top Bar",
    "author": "1P2D",
    "version": (1, 0, 2),
    "blender": (4, 3, 0),
    "location": "Top Bar",
    "description": "Adds viewlayer properties to the top bar",
    "warning": "",
    "doc_url": "https://www.1p2d.com/productivity-addons",
    "category": "User Interface",
}


# This function adds viewlayer checkboxes directly to the topbar
def draw_viewlayer_checkboxes(self, context):
    if context.scene and context.view_layer:
        # Check for warnings
        warnings_rules.check_compositor_settings(context.scene, context)
        
        layout = self.layout
        
        # Add a separator for visual spacing
        layout.separator_spacer()
        
        # Add the "Use for rendering" toggle button as direct property
        row = layout.row(align=True)
        row.alert = not context.view_layer.use
        icon = 'CHECKBOX_HLT' if context.view_layer.use else 'CHECKBOX_DEHLT'
        row.prop(context.view_layer, "use", text="Use for rendering", icon=icon, emboss=False)
        
        # Add the Render Single Layer toggle button as direct property
        row = layout.row(align=True)
        row.alert = context.scene.render.use_single_layer
        icon = 'CHECKBOX_HLT' if context.scene.render.use_single_layer else 'CHECKBOX_DEHLT'
        row.prop(context.scene.render, "use_single_layer", text="Render Single Layer", icon=icon, emboss=False)
        
        # Add warning icon if there are warnings
        row = layout.row(align=True)
        if warnings_rules.ViewLayerWarnings.has_warnings():
            row.operator("wm.viewlayer_warnings", text="", icon='ERROR')
        else:
            row.operator("wm.viewlayer_warnings", text="", icon='CHECKMARK')

# Registration
classes = [
    warnings_rules.TOPBAR_OT_viewlayer_warnings,
    warnings_rules.TOPBAR_MT_viewlayer_warnings_menu,
]

def register():
    for cls in classes:
        bpy.utils.register_class(cls)
    
    # Add our function to the topbar
    bpy.types.TOPBAR_HT_upper_bar.append(draw_viewlayer_checkboxes)

def unregister():
    # Remove our function from the topbar
    bpy.types.TOPBAR_HT_upper_bar.remove(draw_viewlayer_checkboxes)
    
    # Unregister all classes
    for cls in reversed(classes):
        bpy.utils.unregister_class(cls)

if __name__ == "__main__":
    register()